"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
const log4js_1 = require("log4js");
const CodeReaderIpcClient_1 = require("./CodeReaderIpcClient");
const logger = log4js_1.getLogger('CodeReader');
class CodeReader {
    constructor(name) {
        logger.info(`CodeReader '${name}' created`);
        this.name = name;
        this.ipcClient = new CodeReaderIpcClient_1.CodeReaderIpcClient(name);
        this.events = new events_1.EventEmitter();
    }
    start() {
        this.enabled = true;
        this.ipcClient.start();
        this.ipcClient.on('data', data => this.events.emit('data', data));
        this.ipcClient.on('error', e => this.events.emit('error', e));
        logger.info(`CodeReader '${this.name}' started`);
    }
    stop() {
        this.ipcClient.off('data', data => this.events.emit('data', data));
        this.ipcClient.off('error', e => this.events.emit('error', e));
        this.ipcClient.stop();
        this.enabled = false;
        logger.info(`CodeReader '${this.name}' stopped`);
    }
    on(event, listener) {
        this.events.on(event, listener);
        // this.events.on(event, listener);
    }
    off(event, listener) {
        this.events.off(event, listener);
    }
    onCode(code) {
        if (this.enabled === false) {
            return;
        }
        const isNumeric = /^\d+$/.test(code);
        if (!isNumeric) {
            return;
        }
        if (code.length !== 10) {
            return;
        }
        this.ipcClient.send(code);
    }
}
exports.CodeReader = CodeReader;

//# sourceMappingURL=CodeReader.js.map
